import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as RegionalTieredCacheAPI from 'cloudflare/resources/cache/regional-tiered-cache';
export declare class RegionalTieredCache extends APIResource {
    /**
     * Instructs Cloudflare to check a regional hub data center on the way to your
     * upper tier. This can help improve performance for smart and custom tiered cache
     * topologies.
     */
    edit(params: RegionalTieredCacheEditParams, options?: Core.RequestOptions): Core.APIPromise<RegionalTieredCacheEditResponse>;
    /**
     * Instructs Cloudflare to check a regional hub data center on the way to your
     * upper tier. This can help improve performance for smart and custom tiered cache
     * topologies.
     */
    get(params: RegionalTieredCacheGetParams, options?: Core.RequestOptions): Core.APIPromise<RegionalTieredCacheGetResponse>;
}
/**
 * Instructs Cloudflare to check a regional hub data center on the way to your
 * upper tier. This can help improve performance for smart and custom tiered cache
 * topologies.
 */
export interface RegionalTieredCacheEditResponse {
    /**
     * ID of the zone setting.
     */
    id: 'tc_regional';
    /**
     * last time this setting was modified.
     */
    modified_on: string | null;
    /**
     * Instructs Cloudflare to check a regional hub data center on the way to your
     * upper tier. This can help improve performance for smart and custom tiered cache
     * topologies.
     */
    value: RegionalTieredCacheEditResponse.Value;
}
export declare namespace RegionalTieredCacheEditResponse {
    /**
     * Instructs Cloudflare to check a regional hub data center on the way to your
     * upper tier. This can help improve performance for smart and custom tiered cache
     * topologies.
     */
    interface Value {
        /**
         * ID of the zone setting.
         */
        id: 'tc_regional';
        /**
         * last time this setting was modified.
         */
        modified_on: string | null;
    }
}
/**
 * Instructs Cloudflare to check a regional hub data center on the way to your
 * upper tier. This can help improve performance for smart and custom tiered cache
 * topologies.
 */
export interface RegionalTieredCacheGetResponse {
    /**
     * ID of the zone setting.
     */
    id: 'tc_regional';
    /**
     * last time this setting was modified.
     */
    modified_on: string | null;
    /**
     * Instructs Cloudflare to check a regional hub data center on the way to your
     * upper tier. This can help improve performance for smart and custom tiered cache
     * topologies.
     */
    value: RegionalTieredCacheGetResponse.Value;
}
export declare namespace RegionalTieredCacheGetResponse {
    /**
     * Instructs Cloudflare to check a regional hub data center on the way to your
     * upper tier. This can help improve performance for smart and custom tiered cache
     * topologies.
     */
    interface Value {
        /**
         * ID of the zone setting.
         */
        id: 'tc_regional';
        /**
         * last time this setting was modified.
         */
        modified_on: string | null;
    }
}
export interface RegionalTieredCacheEditParams {
    /**
     * Path param: Identifier
     */
    zone_id: string;
    /**
     * Body param: Value of the Regional Tiered Cache zone setting.
     */
    value: 'on' | 'off';
}
export interface RegionalTieredCacheGetParams {
    /**
     * Identifier
     */
    zone_id: string;
}
export declare namespace RegionalTieredCache {
    export import RegionalTieredCacheEditResponse = RegionalTieredCacheAPI.RegionalTieredCacheEditResponse;
    export import RegionalTieredCacheGetResponse = RegionalTieredCacheAPI.RegionalTieredCacheGetResponse;
    export import RegionalTieredCacheEditParams = RegionalTieredCacheAPI.RegionalTieredCacheEditParams;
    export import RegionalTieredCacheGetParams = RegionalTieredCacheAPI.RegionalTieredCacheGetParams;
}
//# sourceMappingURL=regional-tiered-cache.d.ts.map