import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as PermissionsAPI from 'cloudflare/resources/intel/indicator-feeds/permissions';
export declare class Permissions extends APIResource {
    /**
     * Grant permission to indicator feed
     */
    create(params: PermissionCreateParams, options?: Core.RequestOptions): Core.APIPromise<IntelPermissionsUpdate>;
    /**
     * List indicator feed permissions
     */
    list(params: PermissionListParams, options?: Core.RequestOptions): Core.APIPromise<PermissionListResponse>;
    /**
     * Revoke permission to indicator feed
     */
    delete(params: PermissionDeleteParams, options?: Core.RequestOptions): Core.APIPromise<IntelPermissionsUpdate>;
}
export interface IntelPermissionListItem {
    /**
     * The unique identifier for the indicator feed
     */
    id?: number;
    /**
     * The description of the example test
     */
    description?: string;
    /**
     * The name of the indicator feed
     */
    name?: string;
}
export interface IntelPermissionsUpdate {
    /**
     * Whether the update succeeded or not
     */
    success?: boolean;
}
export type PermissionListResponse = Array<IntelPermissionListItem>;
export interface PermissionCreateParams {
    /**
     * Path param: Identifier
     */
    account_id: string;
    /**
     * Body param: The Cloudflare account tag of the account to change permissions on
     */
    account_tag?: string;
    /**
     * Body param: The ID of the feed to add/remove permissions on
     */
    feed_id?: number;
}
export interface PermissionListParams {
    /**
     * Identifier
     */
    account_id: string;
}
export interface PermissionDeleteParams {
    /**
     * Path param: Identifier
     */
    account_id: string;
    /**
     * Body param: The Cloudflare account tag of the account to change permissions on
     */
    account_tag?: string;
    /**
     * Body param: The ID of the feed to add/remove permissions on
     */
    feed_id?: number;
}
export declare namespace Permissions {
    export import IntelPermissionListItem = PermissionsAPI.IntelPermissionListItem;
    export import IntelPermissionsUpdate = PermissionsAPI.IntelPermissionsUpdate;
    export import PermissionListResponse = PermissionsAPI.PermissionListResponse;
    export import PermissionCreateParams = PermissionsAPI.PermissionCreateParams;
    export import PermissionListParams = PermissionsAPI.PermissionListParams;
    export import PermissionDeleteParams = PermissionsAPI.PermissionDeleteParams;
}
//# sourceMappingURL=permissions.d.ts.map