import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as PageShieldAPI from 'cloudflare/resources/page-shield/page-shield';
import * as ConnectionsAPI from 'cloudflare/resources/page-shield/connections';
import * as PoliciesAPI from 'cloudflare/resources/page-shield/policies';
import * as ScriptsAPI from 'cloudflare/resources/page-shield/scripts';
export declare class PageShield extends APIResource {
    policies: PoliciesAPI.Policies;
    connections: ConnectionsAPI.Connections;
    scripts: ScriptsAPI.Scripts;
    /**
     * Updates Page Shield settings.
     */
    update(params: PageShieldUpdateParams, options?: Core.RequestOptions): Core.APIPromise<PageShieldUpdateZoneSettings>;
    /**
     * Fetches the Page Shield settings.
     */
    get(params: PageShieldGetParams, options?: Core.RequestOptions): Core.APIPromise<PageShieldGetZoneSettings>;
}
export interface PageShieldGetZoneSettings {
    /**
     * When true, indicates that Page Shield is enabled.
     */
    enabled?: boolean;
    /**
     * The timestamp of when Page Shield was last updated.
     */
    updated_at?: string;
    /**
     * When true, CSP reports will be sent to
     * https://csp-reporting.cloudflare.com/cdn-cgi/script_monitor/report
     */
    use_cloudflare_reporting_endpoint?: boolean;
    /**
     * When true, the paths associated with connections URLs will also be analyzed.
     */
    use_connection_url_path?: boolean;
}
export interface PageShieldUpdateZoneSettings {
    /**
     * When true, indicates that Page Shield is enabled.
     */
    enabled?: boolean;
    /**
     * The timestamp of when Page Shield was last updated.
     */
    updated_at?: string;
    /**
     * When true, CSP reports will be sent to
     * https://csp-reporting.cloudflare.com/cdn-cgi/script_monitor/report
     */
    use_cloudflare_reporting_endpoint?: boolean;
    /**
     * When true, the paths associated with connections URLs will also be analyzed.
     */
    use_connection_url_path?: boolean;
}
export interface PageShieldUpdateParams {
    /**
     * Path param: Identifier
     */
    zone_id: string;
    /**
     * Body param: When true, indicates that Page Shield is enabled.
     */
    enabled?: boolean;
    /**
     * Body param: When true, CSP reports will be sent to
     * https://csp-reporting.cloudflare.com/cdn-cgi/script_monitor/report
     */
    use_cloudflare_reporting_endpoint?: boolean;
    /**
     * Body param: When true, the paths associated with connections URLs will also be
     * analyzed.
     */
    use_connection_url_path?: boolean;
}
export interface PageShieldGetParams {
    /**
     * Identifier
     */
    zone_id: string;
}
export declare namespace PageShield {
    export import PageShieldGetZoneSettings = PageShieldAPI.PageShieldGetZoneSettings;
    export import PageShieldUpdateZoneSettings = PageShieldAPI.PageShieldUpdateZoneSettings;
    export import PageShieldUpdateParams = PageShieldAPI.PageShieldUpdateParams;
    export import PageShieldGetParams = PageShieldAPI.PageShieldGetParams;
    export import Policies = PoliciesAPI.Policies;
    export import PageShieldPageshieldPolicy = PoliciesAPI.PageShieldPageshieldPolicy;
    export import PolicyListResponse = PoliciesAPI.PolicyListResponse;
    export import PolicyCreateParams = PoliciesAPI.PolicyCreateParams;
    export import PolicyUpdateParams = PoliciesAPI.PolicyUpdateParams;
    export import PolicyListParams = PoliciesAPI.PolicyListParams;
    export import PolicyDeleteParams = PoliciesAPI.PolicyDeleteParams;
    export import PolicyGetParams = PoliciesAPI.PolicyGetParams;
    export import Connections = ConnectionsAPI.Connections;
    export import PageShieldConnection = ConnectionsAPI.PageShieldConnection;
    export import ConnectionListResponse = ConnectionsAPI.ConnectionListResponse;
    export import ConnectionListParams = ConnectionsAPI.ConnectionListParams;
    export import ConnectionGetParams = ConnectionsAPI.ConnectionGetParams;
    export import Scripts = ScriptsAPI.Scripts;
    export import PageShieldScript = ScriptsAPI.PageShieldScript;
    export import ScriptListResponse = ScriptsAPI.ScriptListResponse;
    export import ScriptGetResponse = ScriptsAPI.ScriptGetResponse;
    export import ScriptListParams = ScriptsAPI.ScriptListParams;
    export import ScriptGetParams = ScriptsAPI.ScriptGetParams;
}
//# sourceMappingURL=page-shield.d.ts.map