import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as DeploymentsAPI from 'cloudflare/resources/pages/projects/deployments/deployments';
import * as ProjectsAPI from 'cloudflare/resources/pages/projects/projects';
import * as HistoryAPI from 'cloudflare/resources/pages/projects/deployments/history/history';
export declare class Deployments extends APIResource {
    history: HistoryAPI.History;
    /**
     * Start a new deployment from production. The repository and account must have
     * already been authorized on the Cloudflare Pages dashboard.
     */
    create(projectName: string, params: DeploymentCreateParams, options?: Core.RequestOptions): Core.APIPromise<ProjectsAPI.PagesDeployments>;
    /**
     * Fetch a list of project deployments.
     */
    list(projectName: string, params: DeploymentListParams, options?: Core.RequestOptions): Core.APIPromise<DeploymentListResponse>;
    /**
     * Delete a deployment.
     */
    delete(projectName: string, deploymentId: string, params: DeploymentDeleteParams, options?: Core.RequestOptions): Core.APIPromise<unknown>;
    /**
     * Fetch information about a deployment.
     */
    get(projectName: string, deploymentId: string, params: DeploymentGetParams, options?: Core.RequestOptions): Core.APIPromise<ProjectsAPI.PagesDeployments>;
    /**
     * Retry a previous deployment.
     */
    retry(projectName: string, deploymentId: string, params: DeploymentRetryParams, options?: Core.RequestOptions): Core.APIPromise<ProjectsAPI.PagesDeployments>;
    /**
     * Rollback the production deployment to a previous deployment. You can only
     * rollback to succesful builds on production.
     */
    rollback(projectName: string, deploymentId: string, params: DeploymentRollbackParams, options?: Core.RequestOptions): Core.APIPromise<ProjectsAPI.PagesDeployments>;
}
export type DeploymentListResponse = Array<ProjectsAPI.PagesDeployments>;
export type DeploymentDeleteResponse = unknown;
export interface DeploymentCreateParams {
    /**
     * Path param: Identifier
     */
    account_id: string;
    /**
     * Body param: The branch to build the new deployment from. The `HEAD` of the
     * branch will be used. If omitted, the production branch will be used by default.
     */
    branch?: string;
}
export interface DeploymentListParams {
    /**
     * Identifier
     */
    account_id: string;
}
export interface DeploymentDeleteParams {
    /**
     * Identifier
     */
    account_id: string;
}
export interface DeploymentGetParams {
    /**
     * Identifier
     */
    account_id: string;
}
export interface DeploymentRetryParams {
    /**
     * Identifier
     */
    account_id: string;
}
export interface DeploymentRollbackParams {
    /**
     * Identifier
     */
    account_id: string;
}
export declare namespace Deployments {
    export import DeploymentListResponse = DeploymentsAPI.DeploymentListResponse;
    export import DeploymentDeleteResponse = DeploymentsAPI.DeploymentDeleteResponse;
    export import DeploymentCreateParams = DeploymentsAPI.DeploymentCreateParams;
    export import DeploymentListParams = DeploymentsAPI.DeploymentListParams;
    export import DeploymentDeleteParams = DeploymentsAPI.DeploymentDeleteParams;
    export import DeploymentGetParams = DeploymentsAPI.DeploymentGetParams;
    export import DeploymentRetryParams = DeploymentsAPI.DeploymentRetryParams;
    export import DeploymentRollbackParams = DeploymentsAPI.DeploymentRollbackParams;
    export import History = HistoryAPI.History;
}
//# sourceMappingURL=deployments.d.ts.map