// File generated from our OpenAPI spec by Stainless.
import { APIResource } from 'cloudflare/resource';
import * as DetailsAPI from 'cloudflare/resources/waiting-rooms/events/details';
export class Events extends APIResource {
    constructor() {
        super(...arguments);
        this.details = new DetailsAPI.Details(this._client);
    }
    /**
     * Only available for the Waiting Room Advanced subscription. Creates an event for
     * a waiting room. An event takes place during a specified period of time,
     * temporarily changing the behavior of a waiting room. While the event is active,
     * some of the properties in the event's configuration may either override or
     * inherit from the waiting room's configuration. Note that events cannot overlap
     * with each other, so only one event can be active at a time.
     */
    create(zoneIdentifier, waitingRoomId, body, options) {
        return this._client.post(`/zones/${zoneIdentifier}/waiting_rooms/${waitingRoomId}/events`, {
            body,
            ...options,
        })._thenUnwrap((obj) => obj.result);
    }
    /**
     * Updates a configured event for a waiting room.
     */
    update(zoneIdentifier, waitingRoomId, eventId, body, options) {
        return this._client.put(`/zones/${zoneIdentifier}/waiting_rooms/${waitingRoomId}/events/${eventId}`, {
            body,
            ...options,
        })._thenUnwrap((obj) => obj.result);
    }
    /**
     * Lists events for a waiting room.
     */
    list(zoneIdentifier, waitingRoomId, options) {
        return this._client.get(`/zones/${zoneIdentifier}/waiting_rooms/${waitingRoomId}/events`, options)._thenUnwrap((obj) => obj.result);
    }
    /**
     * Deletes an event for a waiting room.
     */
    delete(zoneIdentifier, waitingRoomId, eventId, options) {
        return this._client.delete(`/zones/${zoneIdentifier}/waiting_rooms/${waitingRoomId}/events/${eventId}`, options)._thenUnwrap((obj) => obj.result);
    }
    /**
     * Patches a configured event for a waiting room.
     */
    edit(zoneIdentifier, waitingRoomId, eventId, body, options) {
        return this._client.patch(`/zones/${zoneIdentifier}/waiting_rooms/${waitingRoomId}/events/${eventId}`, {
            body,
            ...options,
        })._thenUnwrap((obj) => obj.result);
    }
    /**
     * Fetches a single configured event for a waiting room.
     */
    get(zoneIdentifier, waitingRoomId, eventId, options) {
        return this._client.get(`/zones/${zoneIdentifier}/waiting_rooms/${waitingRoomId}/events/${eventId}`, options)._thenUnwrap((obj) => obj.result);
    }
}
(function (Events) {
    Events.Details = DetailsAPI.Details;
})(Events || (Events = {}));
//# sourceMappingURL=events.mjs.map