import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as FallbackDomainsAPI from 'cloudflare/resources/zero-trust/devices/policies/fallback-domains';
export declare class FallbackDomains extends APIResource {
    /**
     * Sets the list of domains to bypass Gateway DNS resolution. These domains will
     * use the specified local DNS resolver instead. This will only apply to the
     * specified device settings profile.
     */
    update(policyId: string, params: FallbackDomainUpdateParams, options?: Core.RequestOptions): Core.APIPromise<FallbackDomainUpdateResponse | null>;
    /**
     * Fetches a list of domains to bypass Gateway DNS resolution. These domains will
     * use the specified local DNS resolver instead.
     */
    list(params: FallbackDomainListParams, options?: Core.RequestOptions): Core.APIPromise<FallbackDomainListResponse | null>;
    /**
     * Fetches the list of domains to bypass Gateway DNS resolution from a specified
     * device settings profile. These domains will use the specified local DNS resolver
     * instead.
     */
    get(policyId: string, params: FallbackDomainGetParams, options?: Core.RequestOptions): Core.APIPromise<FallbackDomainGetResponse | null>;
}
export interface TeamsDevicesFallbackDomain {
    /**
     * The domain suffix to match when resolving locally.
     */
    suffix: string;
    /**
     * A description of the fallback domain, displayed in the client UI.
     */
    description?: string;
    /**
     * A list of IP addresses to handle domain resolution.
     */
    dns_server?: Array<unknown>;
}
export type FallbackDomainUpdateResponse = Array<TeamsDevicesFallbackDomain>;
export type FallbackDomainListResponse = Array<TeamsDevicesFallbackDomain>;
export type FallbackDomainGetResponse = Array<TeamsDevicesFallbackDomain>;
export interface FallbackDomainUpdateParams {
    /**
     * Path param:
     */
    account_id: unknown;
    /**
     * Body param:
     */
    body: Array<TeamsDevicesFallbackDomain>;
}
export interface FallbackDomainListParams {
    account_id: unknown;
}
export interface FallbackDomainGetParams {
    account_id: unknown;
}
export declare namespace FallbackDomains {
    export import TeamsDevicesFallbackDomain = FallbackDomainsAPI.TeamsDevicesFallbackDomain;
    export import FallbackDomainUpdateResponse = FallbackDomainsAPI.FallbackDomainUpdateResponse;
    export import FallbackDomainListResponse = FallbackDomainsAPI.FallbackDomainListResponse;
    export import FallbackDomainGetResponse = FallbackDomainsAPI.FallbackDomainGetResponse;
    export import FallbackDomainUpdateParams = FallbackDomainsAPI.FallbackDomainUpdateParams;
    export import FallbackDomainListParams = FallbackDomainsAPI.FallbackDomainListParams;
    export import FallbackDomainGetParams = FallbackDomainsAPI.FallbackDomainGetParams;
}
//# sourceMappingURL=fallback-domains.d.ts.map