import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as IncludesAPI from 'cloudflare/resources/zero-trust/devices/policies/includes';
export declare class Includes extends APIResource {
    /**
     * Sets the list of routes included in the WARP client's tunnel.
     */
    update(params: IncludeUpdateParams, options?: Core.RequestOptions): Core.APIPromise<IncludeUpdateResponse | null>;
    /**
     * Fetches the list of routes included in the WARP client's tunnel.
     */
    list(params: IncludeListParams, options?: Core.RequestOptions): Core.APIPromise<IncludeListResponse | null>;
    /**
     * Fetches the list of routes included in the WARP client's tunnel for a specific
     * device settings profile.
     */
    get(policyId: string, params: IncludeGetParams, options?: Core.RequestOptions): Core.APIPromise<IncludeGetResponse | null>;
}
export interface TeamsDevicesSplitTunnelInclude {
    /**
     * The address in CIDR format to include in the tunnel. If address is present, host
     * must not be present.
     */
    address: string;
    /**
     * A description of the split tunnel item, displayed in the client UI.
     */
    description: string;
    /**
     * The domain name to include in the tunnel. If host is present, address must not
     * be present.
     */
    host?: string;
}
export type IncludeUpdateResponse = Array<TeamsDevicesSplitTunnelInclude>;
export type IncludeListResponse = Array<TeamsDevicesSplitTunnelInclude>;
export type IncludeGetResponse = Array<TeamsDevicesSplitTunnelInclude>;
export interface IncludeUpdateParams {
    /**
     * Path param:
     */
    account_id: unknown;
    /**
     * Body param:
     */
    body: Array<TeamsDevicesSplitTunnelInclude>;
}
export interface IncludeListParams {
    account_id: unknown;
}
export interface IncludeGetParams {
    account_id: unknown;
}
export declare namespace Includes {
    export import TeamsDevicesSplitTunnelInclude = IncludesAPI.TeamsDevicesSplitTunnelInclude;
    export import IncludeUpdateResponse = IncludesAPI.IncludeUpdateResponse;
    export import IncludeListResponse = IncludesAPI.IncludeListResponse;
    export import IncludeGetResponse = IncludesAPI.IncludeGetResponse;
    export import IncludeUpdateParams = IncludesAPI.IncludeUpdateParams;
    export import IncludeListParams = IncludesAPI.IncludeListParams;
    export import IncludeGetParams = IncludesAPI.IncludeGetParams;
}
//# sourceMappingURL=includes.d.ts.map