import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as SettingsAPI from 'cloudflare/resources/zero-trust/devices/settings';
export declare class Settings extends APIResource {
    /**
     * Updates the current device settings for a Zero Trust account.
     */
    update(params: SettingUpdateParams, options?: Core.RequestOptions): Core.APIPromise<TeamsDevicesZeroTrustAccountDeviceSettings | null>;
    /**
     * Describes the current device settings for a Zero Trust account.
     */
    list(params: SettingListParams, options?: Core.RequestOptions): Core.APIPromise<TeamsDevicesZeroTrustAccountDeviceSettings | null>;
}
export interface TeamsDevicesZeroTrustAccountDeviceSettings {
    /**
     * Enable gateway proxy filtering on TCP.
     */
    gateway_proxy_enabled?: boolean;
    /**
     * Enable gateway proxy filtering on UDP.
     */
    gateway_udp_proxy_enabled?: boolean;
    /**
     * Enable installation of cloudflare managed root certificate.
     */
    root_certificate_installation_enabled?: boolean;
    /**
     * Enable using CGNAT virtual IPv4.
     */
    use_zt_virtual_ip?: boolean;
}
export interface SettingUpdateParams {
    /**
     * Path param:
     */
    account_id: unknown;
    /**
     * Body param: Enable gateway proxy filtering on TCP.
     */
    gateway_proxy_enabled?: boolean;
    /**
     * Body param: Enable gateway proxy filtering on UDP.
     */
    gateway_udp_proxy_enabled?: boolean;
    /**
     * Body param: Enable installation of cloudflare managed root certificate.
     */
    root_certificate_installation_enabled?: boolean;
    /**
     * Body param: Enable using CGNAT virtual IPv4.
     */
    use_zt_virtual_ip?: boolean;
}
export interface SettingListParams {
    account_id: unknown;
}
export declare namespace Settings {
    export import TeamsDevicesZeroTrustAccountDeviceSettings = SettingsAPI.TeamsDevicesZeroTrustAccountDeviceSettings;
    export import SettingUpdateParams = SettingsAPI.SettingUpdateParams;
    export import SettingListParams = SettingsAPI.SettingListParams;
}
//# sourceMappingURL=settings.d.ts.map