import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as ImageResizingAPI from 'cloudflare/resources/zones/settings/image-resizing';
export declare class ImageResizing extends APIResource {
    /**
     * Image Resizing provides on-demand resizing, conversion and optimisation for
     * images served through Cloudflare's network. Refer to the
     * [Image Resizing documentation](https://developers.cloudflare.com/images/) for
     * more information.
     */
    edit(params: ImageResizingEditParams, options?: Core.RequestOptions): Core.APIPromise<ZonesImageResizing>;
    /**
     * Image Resizing provides on-demand resizing, conversion and optimisation for
     * images served through Cloudflare's network. Refer to the
     * [Image Resizing documentation](https://developers.cloudflare.com/images/) for
     * more information.
     */
    get(params: ImageResizingGetParams, options?: Core.RequestOptions): Core.APIPromise<ZonesImageResizing>;
}
/**
 * Image Resizing provides on-demand resizing, conversion and optimisation for
 * images served through Cloudflare's network. Refer to the
 * [Image Resizing documentation](https://developers.cloudflare.com/images/) for
 * more information.
 */
export interface ZonesImageResizing {
    /**
     * ID of the zone setting.
     */
    id: 'image_resizing';
    /**
     * Current value of the zone setting.
     */
    value: 'on' | 'off' | 'open';
    /**
     * Whether or not this setting can be modified for this zone (based on your
     * Cloudflare plan level).
     */
    editable?: true | false;
    /**
     * last time this setting was modified.
     */
    modified_on?: string | null;
}
export interface ImageResizingEditParams {
    /**
     * Path param: Identifier
     */
    zone_id: string;
    /**
     * Body param: Image Resizing provides on-demand resizing, conversion and
     * optimisation for images served through Cloudflare's network. Refer to the
     * [Image Resizing documentation](https://developers.cloudflare.com/images/) for
     * more information.
     */
    value: ZonesImageResizing;
}
export interface ImageResizingGetParams {
    /**
     * Identifier
     */
    zone_id: string;
}
export declare namespace ImageResizing {
    export import ZonesImageResizing = ImageResizingAPI.ZonesImageResizing;
    export import ImageResizingEditParams = ImageResizingAPI.ImageResizingEditParams;
    export import ImageResizingGetParams = ImageResizingAPI.ImageResizingGetParams;
}
//# sourceMappingURL=image-resizing.d.ts.map