import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as TrueClientIPHeaderAPI from 'cloudflare/resources/zones/settings/true-client-ip-header';
export declare class TrueClientIPHeader extends APIResource {
    /**
     * Allows customer to continue to use True Client IP (Akamai feature) in the
     * headers we send to the origin. This is limited to Enterprise Zones.
     */
    edit(params: TrueClientIPHeaderEditParams, options?: Core.RequestOptions): Core.APIPromise<ZonesTrueClientIPHeader>;
    /**
     * Allows customer to continue to use True Client IP (Akamai feature) in the
     * headers we send to the origin. This is limited to Enterprise Zones.
     */
    get(params: TrueClientIPHeaderGetParams, options?: Core.RequestOptions): Core.APIPromise<ZonesTrueClientIPHeader>;
}
/**
 * Allows customer to continue to use True Client IP (Akamai feature) in the
 * headers we send to the origin. This is limited to Enterprise Zones.
 */
export interface ZonesTrueClientIPHeader {
    /**
     * ID of the zone setting.
     */
    id: 'true_client_ip_header';
    /**
     * Current value of the zone setting.
     */
    value: 'on' | 'off';
    /**
     * Whether or not this setting can be modified for this zone (based on your
     * Cloudflare plan level).
     */
    editable?: true | false;
    /**
     * last time this setting was modified.
     */
    modified_on?: string | null;
}
export interface TrueClientIPHeaderEditParams {
    /**
     * Path param: Identifier
     */
    zone_id: string;
    /**
     * Body param: Value of the zone setting.
     */
    value: 'on' | 'off';
}
export interface TrueClientIPHeaderGetParams {
    /**
     * Identifier
     */
    zone_id: string;
}
export declare namespace TrueClientIPHeader {
    export import ZonesTrueClientIPHeader = TrueClientIPHeaderAPI.ZonesTrueClientIPHeader;
    export import TrueClientIPHeaderEditParams = TrueClientIPHeaderAPI.TrueClientIPHeaderEditParams;
    export import TrueClientIPHeaderGetParams = TrueClientIPHeaderAPI.TrueClientIPHeaderGetParams;
}
//# sourceMappingURL=true-client-ip-header.d.ts.map